==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGridClipboardEventDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridClipboardEventDescription } from "./WebGridClipboardEventDescription";
/**
 * @hidden
 */
var WebGridClipboardEventDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridClipboardEventDescriptionMetadata, _super);
    function WebGridClipboardEventDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridClipboardEventDescriptionMetadata.b = function (a) {
        if (WebGridClipboardEventDescriptionMetadata.a == null) {
            WebGridClipboardEventDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridClipboardEventDescriptionMetadata.c(WebGridClipboardEventDescriptionMetadata.a);
        }
        if (a.j(WebGridClipboardEventDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridClipboardEventDescriptionMetadata.a);
    };
    WebGridClipboardEventDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridClipboardEvent");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("DataRef", "(w:Data,wf:Data)DataRef:object");
        a.item("Cancel", "Boolean");
    };
    WebGridClipboardEventDescriptionMetadata.d = function (a) {
        WebGridClipboardEventDescriptionMetadata.b(a);
        a.aa("WebGridClipboardEvent", function () { return new WebGridClipboardEventDescription(); });
        a.z("WebGridClipboardEvent", WebGridClipboardEventDescriptionMetadata.a);
    };
    WebGridClipboardEventDescriptionMetadata.$t = markType(WebGridClipboardEventDescriptionMetadata, 'WebGridClipboardEventDescriptionMetadata');
    WebGridClipboardEventDescriptionMetadata.a = null;
    return WebGridClipboardEventDescriptionMetadata;
}(Base));
export { WebGridClipboardEventDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGridClipboardEventDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridClipboardEventDescription } from "./WebGridClipboardEventDescription";
/**
 * @hidden
 */
var WebGridClipboardEventDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridClipboardEventDescriptionMetadata, _super);
    function WebGridClipboardEventDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridClipboardEventDescriptionMetadata.b = function (a) {
        if (WebGridClipboardEventDescriptionMetadata.a == null) {
            WebGridClipboardEventDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridClipboardEventDescriptionMetadata.c(WebGridClipboardEventDescriptionMetadata.a);
        }
        if (a.k(WebGridClipboardEventDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridClipboardEventDescriptionMetadata.a);
    };
    WebGridClipboardEventDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridClipboardEvent");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("DataRef", "(w:Data,wf:Data)DataRef:object");
        a.item("Cancel", "Boolean");
    };
    WebGridClipboardEventDescriptionMetadata.d = function (a) {
        WebGridClipboardEventDescriptionMetadata.b(a);
        a.ac("WebGridClipboardEvent", function () { return new WebGridClipboardEventDescription(); });
        a.ab("WebGridClipboardEvent", WebGridClipboardEventDescriptionMetadata.a);
    };
    WebGridClipboardEventDescriptionMetadata.$t = markType(WebGridClipboardEventDescriptionMetadata, 'WebGridClipboardEventDescriptionMetadata');
    WebGridClipboardEventDescriptionMetadata.a = null;
    return WebGridClipboardEventDescriptionMetadata;
}(Base));
export { WebGridClipboardEventDescriptionMetadata };
